@@ -28,7 +28,7 @@
 #ifndef HAVE_BACON_VIDEO_WIDGET_H
 #define HAVE_BACON_VIDEO_WIDGET_H
 
-#include <gtk/gtk.h>
+#include <clutter-gtk/clutter-gtk.h>
 /* for optical disc enumeration type */
 #include <totem-disc.h>
 
@@ -51,7 +51,7 @@ typedef struct BaconVideoWidgetCommon BaconVideoWidgetCommon;
  **/
 typedef struct {
 	/*< private >*/
-	GtkEventBox parent;
+	GtkClutterEmbed parent;
 	BaconVideoWidgetPrivate *priv;
 } BaconVideoWidget;
 
@@ -62,7 +62,7 @@ typedef struct {
  **/
 typedef struct {
 	/*< private >*/
-	GtkEventBoxClass parent_class;
+	GtkClutterEmbedClass parent_class;
 
 	void (*error) (GtkWidget *bvw, const char *message,
                        gboolean playback_stopped, gboolean fatal);
@@ -139,30 +139,8 @@ typedef enum {
 GQuark bacon_video_widget_error_quark		 (void) G_GNUC_CONST;
 GType bacon_video_widget_get_type                (void);
 GOptionGroup* bacon_video_widget_get_option_group (void);
-/* This can be used if the app does not use popt */
-void bacon_video_widget_init_backend		 (int *argc, char ***argv);
 
-/**
- * BvwUseType:
- * @BVW_USE_TYPE_VIDEO: fully-featured with video, audio, capture and metadata support
- * @BVW_USE_TYPE_AUDIO: audio and metadata support
- * @BVW_USE_TYPE_CAPTURE: capture support only
- * @BVW_USE_TYPE_METADATA: metadata support only
- *
- * The purpose for which a #BaconVideoWidget will be used, as specified to
- * bacon_video_widget_new(). This determines which features will be enabled
- * in the created widget.
- **/
-typedef enum {
-	BVW_USE_TYPE_VIDEO,
-	BVW_USE_TYPE_AUDIO,
-	BVW_USE_TYPE_CAPTURE,
-	BVW_USE_TYPE_METADATA
-} BvwUseType;
-
-GtkWidget *bacon_video_widget_new		 (int width, int height,
-						  BvwUseType type,
-						  GError **error);
+GtkWidget *bacon_video_widget_new		 (GError **error);
 
 char *bacon_video_widget_get_backend_name (BaconVideoWidget *bvw);
 
@@ -183,6 +161,7 @@ gboolean bacon_video_widget_seek		 (BaconVideoWidget *bvw,
 						  GError **error);
 gboolean bacon_video_widget_seek_time		 (BaconVideoWidget *bvw,
 						  gint64 _time,
+						  gboolean accurate,
 						  GError **error);
 gboolean bacon_video_widget_step		 (BaconVideoWidget *bvw,
 						  gboolean forward,
@@ -203,9 +182,7 @@ double bacon_video_widget_get_volume             (BaconVideoWidget *bvw);
 
 /* Properties */
 void bacon_video_widget_set_logo		 (BaconVideoWidget *bvw,
-						  const char *filename);
-void bacon_video_widget_set_logo_pixbuf		 (BaconVideoWidget *bvw,
-						  GdkPixbuf *logo);
+						  const char *name);
 void  bacon_video_widget_set_logo_mode		 (BaconVideoWidget *bvw,
 						  gboolean logo_mode);
 gboolean bacon_video_widget_get_logo_mode	 (BaconVideoWidget *bvw);
@@ -221,6 +198,38 @@ gboolean bacon_video_widget_get_auto_resize	 (BaconVideoWidget *bvw);
 void bacon_video_widget_set_auto_resize		 (BaconVideoWidget *bvw,
 						  gboolean auto_resize);
 
+/**
+ * BvwConnectionSpeed:
+ * @BVW_SPEED_14_4_MODEM: 14.4 Kbps Modem
+ * @BVW_SPEED_19_2_MODEM: 19.2 Kbps Modem
+ * @BVW_SPEED_28_8_MODEM: 28.8 Kbps Modem
+ * @BVW_SPEED_33_6_MODEM: 33.6 Kbps Modem
+ * @BVW_SPEED_34_4_MODEM: 34.4 Kbps Modem
+ * @BVW_SPEED_56_ISDN: 56 Kbps Modem/ISDN
+ * @BVW_SPEED_112_ISDN: 112 Kbps Dual ISDN/DSL
+ * @BVW_SPEED_256_DSL: 256 Kbps DSL/Cable
+ * @BVW_SPEED_384_DSL: 384 Kbps DSL/Cable
+ * @BVW_SPEED_512_DSL: 512 Kbps DSL/Cable
+ * @BVW_SPEED_1500_T1: 1.5 Mbps T1/Intranet/LAN
+ * @BVW_SPEED_LAN: Intranet/LAN
+ *
+ * The different connection speeds understood by bacon_video_widget_set_connection_speed().
+ */
+typedef enum {
+	BVW_SPEED_14_4_MODEM = 0,
+	BVW_SPEED_19_2_MODEM,
+	BVW_SPEED_28_8_MODEM,
+	BVW_SPEED_33_6_MODEM,
+	BVW_SPEED_34_4_MODEM,
+	BVW_SPEED_56_ISDN,
+	BVW_SPEED_112_ISDN,
+	BVW_SPEED_256_DSL,
+	BVW_SPEED_384_DSL,
+	BVW_SPEED_512_DSL,
+	BVW_SPEED_1500_T1,
+	BVW_SPEED_LAN
+} BvwConnectionSpeed;
+
 void bacon_video_widget_set_connection_speed     (BaconVideoWidget *bvw,
 						  int speed);
 int bacon_video_widget_get_connection_speed      (BaconVideoWidget *bvw);
@@ -251,6 +260,7 @@ void bacon_video_widget_set_referrer             (BaconVideoWidget *bvw,
  * @BVW_INFO_DURATION: the stream's duration, in seconds
  * @BVW_INFO_TRACK_NUMBER: the track number of the work on the album
  * @BVW_INFO_COVER: a #GdkPixbuf of the cover artwork
+ * @BVW_INFO_CONTAINER: the type of stream container
  * @BVW_INFO_HAS_VIDEO: whether the stream has video
  * @BVW_INFO_DIMENSION_X: the video's width, in pixels
  * @BVW_INFO_DIMENSION_Y: the video's height, in pixels
@@ -275,6 +285,7 @@ typedef enum {
 	BVW_INFO_DURATION,
 	BVW_INFO_TRACK_NUMBER,
 	BVW_INFO_COVER,
+	BVW_INFO_CONTAINER,
 	/* Video */
 	BVW_INFO_HAS_VIDEO,
 	BVW_INFO_DIMENSION_X,
@@ -296,31 +307,29 @@ void bacon_video_widget_get_metadata		 (BaconVideoWidget *bvw,
 
 /* Visualisation functions */
 /**
- * BvwVisualsQuality:
- * @VISUAL_SMALL: small size (240×15)
- * @VISUAL_NORMAL: normal size (320×25)
- * @VISUAL_LARGE: large size (480×25)
- * @VISUAL_EXTRA_LARGE: extra large size (600×30)
- * @NUM_VISUAL_QUALITIES: the number of visual qualities available
+ * BvwVisualizationQuality:
+ * @BVW_VISUALIZATION_SMALL: small size (240×15)
+ * @BVW_VISUALIZATION_NORMAL: normal size (320×25)
+ * @BVW_VISUALIZATION_LARGE: large size (480×25)
+ * @BVW_VISUALIZATION_EXTRA_LARGE: extra large size (600×30)
  *
  * The different visualisation sizes or qualities available for use
- * with bacon_video_widget_set_visuals_quality().
+ * with bacon_video_widget_set_visualization_quality().
  **/
 typedef enum {
-	VISUAL_SMALL = 0,
-	VISUAL_NORMAL,
-	VISUAL_LARGE,
-	VISUAL_EXTRA_LARGE,
-	NUM_VISUAL_QUALITIES
-} BvwVisualsQuality;
+	BVW_VISUALIZATION_SMALL = 0,
+	BVW_VISUALIZATION_NORMAL,
+	BVW_VISUALIZATION_LARGE,
+	BVW_VISUALIZATION_EXTRA_LARGE
+} BvwVisualizationQuality;
 
-void bacon_video_widget_set_show_visuals	  (BaconVideoWidget *bvw,
-						   gboolean show_visuals);
-GList *bacon_video_widget_get_visuals_list	  (BaconVideoWidget *bvw);
-gboolean bacon_video_widget_set_visuals		  (BaconVideoWidget *bvw,
+void bacon_video_widget_set_show_visualizations	  (BaconVideoWidget *bvw,
+						   gboolean show_visualizations);
+GList *bacon_video_widget_get_visualization_list  (BaconVideoWidget *bvw);
+void bacon_video_widget_set_visualization	  (BaconVideoWidget *bvw,
 						   const char *name);
-void bacon_video_widget_set_visuals_quality	  (BaconVideoWidget *bvw,
-						   BvwVisualsQuality quality);
+void bacon_video_widget_set_visualization_quality (BaconVideoWidget *bvw,
+						   BvwVisualizationQuality quality);
 
 /* Picture settings */
 /**
@@ -359,7 +368,19 @@ typedef enum {
 	BVW_RATIO_DVB = 4
 } BvwAspectRatio;
 
-gboolean bacon_video_widget_can_deinterlace	 (BaconVideoWidget *bvw);
+/**
+ * BvwZoomMode:
+ * @BVW_ZOOM_NONE: No video zooming/cropping
+ * @BVW_ZOOM_EXPAND: Fill area with video, and crop the excess
+ *
+ * The zoom mode used by the video widget, as set by
+ * bacon_video_widget_set_zoom().
+ **/
+typedef enum {
+	BVW_ZOOM_NONE = 0,
+	BVW_ZOOM_EXPAND = 1
+} BvwZoomMode;
+
 void bacon_video_widget_set_deinterlacing        (BaconVideoWidget *bvw,
 						  gboolean deinterlace);
 gboolean bacon_video_widget_get_deinterlacing    (BaconVideoWidget *bvw);
@@ -373,8 +394,8 @@ void bacon_video_widget_set_scale_ratio          (BaconVideoWidget *bvw,
 						  float ratio);
 
 void bacon_video_widget_set_zoom		 (BaconVideoWidget *bvw,
-						  double zoom);
-double bacon_video_widget_get_zoom		 (BaconVideoWidget *bvw);
+						  BvwZoomMode       mode);
+BvwZoomMode bacon_video_widget_get_zoom		 (BaconVideoWidget *bvw);
 
 int bacon_video_widget_get_video_property        (BaconVideoWidget *bvw,
 						  BvwVideoProperty type);
@@ -382,7 +403,10 @@ void bacon_video_widget_set_video_property       (BaconVideoWidget *bvw,
 						  BvwVideoProperty type,
 						  int value);
 
+void bacon_video_widget_set_next_angle           (BaconVideoWidget *bvw);
+
 gboolean bacon_video_widget_has_menus            (BaconVideoWidget *bvw);
+gboolean bacon_video_widget_has_angles           (BaconVideoWidget *bvw);
 
 /* DVD functions */
 /**
@@ -397,8 +421,6 @@ gboolean bacon_video_widget_has_menus            (BaconVideoWidget *bvw);
  * @BVW_DVD_PREV_CHAPTER: the previous chapter
  * @BVW_DVD_NEXT_TITLE: the next title in the current chapter
  * @BVW_DVD_PREV_TITLE: the previous title in the current chapter
- * @BVW_DVD_NEXT_ANGLE: the next angle
- * @BVW_DVD_PREV_ANGLE: the previous angle
  * @BVW_DVD_ROOT_MENU_UP: go up in the menu
  * @BVW_DVD_ROOT_MENU_DOWN: go down in the menu
  * @BVW_DVD_ROOT_MENU_LEFT: go left in the menu
@@ -419,8 +441,6 @@ typedef enum {
 	BVW_DVD_PREV_CHAPTER,
 	BVW_DVD_NEXT_TITLE,
 	BVW_DVD_PREV_TITLE,
-	BVW_DVD_NEXT_ANGLE,
-	BVW_DVD_PREV_ANGLE,
 	BVW_DVD_ROOT_MENU_UP,
 	BVW_DVD_ROOT_MENU_DOWN,
 	BVW_DVD_ROOT_MENU_LEFT,
@@ -450,7 +470,7 @@ GdkPixbuf *bacon_video_widget_get_current_frame (BaconVideoWidget *bvw);
 
 /* Audio-out functions */
 /**
- * BvwAudioOutType:
+ * BvwAudioOutputType:
  * @BVW_AUDIO_SOUND_STEREO: stereo output
  * @BVW_AUDIO_SOUND_4CHANNEL: 4-channel output
  * @BVW_AUDIO_SOUND_41CHANNEL: 4.1-channel output
@@ -458,7 +478,7 @@ GdkPixbuf *bacon_video_widget_get_current_frame (BaconVideoWidget *bvw);
  * @BVW_AUDIO_SOUND_51CHANNEL: 5.1-channel output
  * @BVW_AUDIO_SOUND_AC3PASSTHRU: AC3 passthrough output
  *
- * The audio output types available for use with bacon_video_widget_set_audio_out_type().
+ * The audio output types available for use with bacon_video_widget_set_audio_output_type().
  **/
 typedef enum {
 	BVW_AUDIO_SOUND_STEREO,
@@ -467,12 +487,12 @@ typedef enum {
 	BVW_AUDIO_SOUND_5CHANNEL,
 	BVW_AUDIO_SOUND_51CHANNEL,
 	BVW_AUDIO_SOUND_AC3PASSTHRU
-} BvwAudioOutType;
+} BvwAudioOutputType;
 
-BvwAudioOutType bacon_video_widget_get_audio_out_type
+BvwAudioOutputType bacon_video_widget_get_audio_output_type
 						 (BaconVideoWidget *bvw);
-gboolean bacon_video_widget_set_audio_out_type   (BaconVideoWidget *bvw,
-						  BvwAudioOutType type);
+void bacon_video_widget_set_audio_output_type    (BaconVideoWidget *bvw,
+						  BvwAudioOutputType type);
 
 G_END_DECLS
 
