@@ -60,7 +60,7 @@ static void totem_save_file_plugin_copy (GtkAction *action,
 					 TotemSaveFilePlugin *pi);
 
 static GtkActionEntry totem_save_file_plugin_actions [] = {
-	{ "SaveFile", "save-as", N_("Save a Copy..."), NULL,
+	{ "SaveFile", "save-as", N_("Save a Copy..."), "<Ctrl>E",
 		N_("Save a copy of the movie"),
 		G_CALLBACK (totem_save_file_plugin_copy) },
 };
@@ -350,7 +350,7 @@ impl_deactivate (PeasActivatable *plugin)
 	g_free (priv->mrl);
 	priv->mrl = NULL;
 	g_free (priv->name);
-	priv->mrl = NULL;
+	priv->name = NULL;
 	g_free (priv->save_uri);
 	priv->save_uri = NULL;
 }
