@@ -134,7 +134,7 @@ totem_video_list_class_init (TotemVideoListClass *klass)
 	 * If it's set to -1, no tooltips shall be displayed.
 	 **/
 	g_object_class_install_property (object_class, PROP_TOOLTIP_COLUMN,
-				g_param_spec_int ("tooltip-column", NULL, NULL,
+				g_param_spec_int ("tooltip-column", "Tooltip column", "The column number of the column containing tooltips.",
 					-1, G_MAXINT, -1, G_PARAM_READWRITE));
 
 	/**
@@ -144,7 +144,7 @@ totem_video_list_class_init (TotemVideoListClass *klass)
 	 * If it's set to -1, video rows will not be activatable (e.g. by double-clicking them).
 	 **/
 	g_object_class_install_property (object_class, PROP_MRL_COLUMN,
-				g_param_spec_int ("mrl-column", NULL, NULL,
+				g_param_spec_int ("mrl-column", "MRL column", "The column number of the column containing MRLs of the videos.",
 					-1, G_MAXINT, -1, G_PARAM_READWRITE));
 
 	/**
@@ -154,7 +154,7 @@ totem_video_list_class_init (TotemVideoListClass *klass)
 	 **/
 	/* FIXME: Is there no better way to do this? */
 	g_object_class_install_property (object_class, PROP_TOTEM,
-				g_param_spec_object ("totem", NULL, NULL,
+				g_param_spec_object ("totem", "Totem", "A TotemObject for integration purposes.",
 					TOTEM_TYPE_OBJECT, G_PARAM_READWRITE));
 
 	/**
@@ -166,7 +166,8 @@ totem_video_list_class_init (TotemVideoListClass *klass)
 	 * Since: 2.90.6
 	 **/
 	g_object_class_install_property (object_class, PROP_SHOW_TOOLTIP_URI,
-				g_param_spec_boolean ("show-tooltip-uri", NULL, NULL,
+				g_param_spec_boolean ("show-tooltip-uri", "Show tooltip URI?",
+				                      "Whether the URI of each video will be displayed in the tooltip for that video.",
 					TRUE, G_PARAM_READWRITE));
 
 	/**
@@ -485,6 +486,7 @@ add_to_playlist_action_callback (GtkAction *action, TotemVideoList *self)
 	GtkTreePath *path;
 	GtkTreeIter iter;
 	gchar *mrl, *display_name;
+	GList *mrl_list = NULL;
 	GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (self));
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (self));
 	GList *l = gtk_tree_selection_get_selected_rows (selection, NULL);
@@ -506,7 +508,7 @@ add_to_playlist_action_callback (GtkAction *action, TotemVideoList *self)
 			continue;
 		}
 
-		totem_playlist_add_mrl (playlist, mrl, display_name, TRUE, NULL, NULL, NULL);
+		mrl_list = g_list_prepend (mrl_list, totem_playlist_mrl_data_new (mrl, display_name));
 
 		g_free (mrl);
 		g_free (display_name);
@@ -514,6 +516,10 @@ add_to_playlist_action_callback (GtkAction *action, TotemVideoList *self)
 
 	g_list_foreach (l, (GFunc) gtk_tree_path_free, NULL);
 	g_list_free (l);
+
+	/* Asynchronously add all the MRLs to the playlist in order */
+	if (mrl_list != NULL)
+		totem_playlist_add_mrls (playlist, g_list_reverse (mrl_list), TRUE, NULL, NULL, NULL);
 }
 
 void
